/* the omission of the Italic variants mirrors what Movim upstream does */

@font-face {
	font-family:'Open Sans';
	font-style:normal;
	font-weight:300;
	src:local('Open Sans Light'), local('OpenSans-Light'),
	    url('../open-sans/OpenSans-Light.ttf') format("truetype");
}

@font-face {
	font-family:'Open Sans';
	font-style:normal;
	font-weight:400;
	src:local('Open Sans Regular'), local('OpenSans-Regular'),
	    url('../open-sans/OpenSans-Regular.ttf') format("truetype");
}

@font-face {
	font-family:'Open Sans';
	font-style:normal;
	font-weight:600;
	src:local('Open Sans SemiBold'), local('OpenSans-SemiBold'),
	    url('../open-sans/OpenSans-Semibold.ttf') format("truetype");
}

@font-face {
	font-family:'Open Sans';
	font-style:normal;
	font-weight:700;
	src:local('Open Sans Bold'), local('OpenSans-Bold'),
	    url('../open-sans/OpenSans-Bold.ttf') format("truetype");
}

@font-face {
	font-family:'Open Sans';
	font-style:normal;
	font-weight:800;
	src:local('Open Sans ExtraBold'), local('OpenSans-ExtraBold'),
	    url('../open-sans/OpenSans-ExtraBold.ttf') format("truetype");
}
