<?php

require_once('Composer/Autoload/ClassLoader.php');
require_once('/usr/share/php/HTMLPurifier.composer.php');
require_once('/usr/share/php/Illuminate/Support/helpers.php');
require_once('/usr/share/php/GuzzleHttp/Psr7/functions_include.php');
require_once('/usr/share/php/React/Promise/functions_include.php');
require_once('/usr/share/php/React/Promise/Stream/functions_include.php');
require_once('/usr/share/php/React/Promise/Timer/functions.php');

$movim_autoloader = new \Composer\Autoload\ClassLoader();
$movim_autoloader->setUseIncludePath(true);
$movim_autoloader->add('App', '/usr/share/movim/app');
$movim_autoloader->register();
